/*
** Module   : NativePty.java
** Abstract : native PTY interface.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------Description-----------------
** 001 MAG 20140318 First version.
*/

package com.goldencode.terminal;

/**
 * This class is the native PTY interface. 
 * 
 * @author mag
 *
 */
public class NativePty
{
   /** Load native code. */
   static
   {
      System.loadLibrary("p2j");
   }
   
   /** Master INP PTY descriptor */
   protected int mfd_inp;

   /** Master OUT PTY descriptor */
   protected int mfd_out;
   
   /** Child process PID */
   protected int pid;
   
   /**
    * Spawn a child shell process.
    * "mfd" field is set to PTY master descriptor.
    * 
    * @param   term
    *          Terminal environment TERM=vt100
    * @param   cmdLine
    *          Command line arguments.
    * 
    * @return  Child process id or -1 on error.
    */
   protected native int shell(String term, String[] cmdLine);

   /**
    * Wait for child process to exit.
    * 
    * @param   pid
    *          Child process id.
    *          
    * @return  Process status or -1 on error.
    */
   protected native int waitPid(int pid);

   /**
    * Read from master PTY descriptor.
    * 
    * @param   mfd_inp
    *          Master PTY descriptor.
    *          
    * @return  A byte array of characters read.
    */
   protected native byte[] read(int mfd_inp);

   /**
    * Write a byte array to master PTY.
    * 
    * @param   mfd_out
    *          Master PTY descriptor
    * @param   data
    *          Data to write.
    *          
    * @return  Number of bytes written.
    */
   protected native int write(int mfd_out, byte[] data);
}
